#
# spec file for package liblangtag
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname liblangtag1
Name:           liblangtag
Version:        0.5.7
Release:        2.3
Summary:        An interface library to access tags for identifying languages
License:        LGPL-3.0+ or MPL-2.0
Group:          Productivity/Publishing/Word
Url:            http://tagoh.bitbucket.org/liblangtag/
Source0:        https://bitbucket.org/tagoh/%{name}/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  check
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  glib2-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package -n %{libname}
Summary:        C++ library for identification of the language from tags
Group:          System/Libraries

%description -n %{libname}
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package devel
Summary:        Files for Developing with %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glib2-devel

%description devel
%{name} is an interface library to access tags for identifying
languages.

This package contains the %{name} development files.

%package doc
Summary:        Documentation of %{name} API
Group:          Documentation/HTML
%if 0%{?suse_version} > 1200
BuildArch:      noarch
%endif

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-static \
	--enable-test \
	--disable-introspection \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags} V=1

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%dir %{_libdir}/%{name}/
%dir %{_datadir}/%{name}/
%{_libdir}/*.so.1*
%{_libdir}/%{name}/*
%{_datadir}/%{name}/*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_includedir}/%{name}*

%files doc
%defattr(-,root,root)
%doc COPYING
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Tue Jul 14 2015 tchvatal@suse.com
- Version bump to 0.5.7:
  * Tons of fixes between 0.5.4 and this release. Read NEWS file
* Wed Jun 25 2014 tchvatal@suse.com
- Version bump to 0.5.4:
  * Various small items detailed in NEWS file
  * Removed language stubtag registry
* Tue May 20 2014 tchvatal@suse.com
- Add condition around noarch doc subpkg to work with SLE11
* Mon May 12 2014 tchvatal@suse.com
- Version bump to 0.5.3:
  * Various small fixes detailed in NEWS file
* Mon Sep 23 2013 tchvatal@suse.com
- Version bump to 0.5.2
  * Various autootool fixes
  * coverity fixes
  * For more read up NEWS file
* Wed May  1 2013 tchvatal@suse.com
- Version bump to 0.5.1
  * resolves abi compatibility issues.
* Sat Apr 27 2013 tchvatal@suse.com
- Version bump to 0.5
  * Enhancements:
  * Iterator support
  * Add lt_tag_convert_from_locale_string()
  * Bug Fixes:
  * Fix wrong traversal on keys
  * Fix xml parser for tags in range
  * Improve portability
  * Fix broken lt_tag_transform()
  * Fix the build issue when builddir != srcdir
  * Fix broken lt_tag_convert_from_locale()
  * Fix memory leaks
  * Fix linker issue
  * Use secure_getenv if available
  * more
- Remove upstreamed patches.
* Sat Apr 20 2013 tchvatal@suse.com
- Use full download url.
- Apply patches from git to fix few build issues.
* Wed Nov 14 2012 tchvatal@suse.com
- Fix Requires to demand glib2-devel not gtk1 variant
  (thanks coolo)
  * Fix copy&pasto in one summary.
* Tue Nov 13 2012 tchvatal@suse.com
- Use both lpgl and mpl licenses.
  * thanks to babelworx for the hint (merge request fails to
    complete so doing it myself).
* Fri Nov  9 2012 tchvatal@suse.com
- Fix desc not to contain mention of libexttextcat.
* Wed Nov  7 2012 tchvatal@suse.com
- Add missing directory to the list.
* Tue Nov  6 2012 tchvatal@suse.com
- Initial package. Version 0.4.0.
